* motile_toolbox version or commit:
* Python version:
* Operating System:

### Bug or feature?

Are you reporting a bug or adding a new feature? Perhaps you want more documentation?
Please tell us here and tag the issue appropriately.

### Description

Describe the bug you want fixed, the feature you want to see, etc.
If you are requesting a new feature, please say why you think that feature is important and belongs in this library, and any guesses on how to implement it.

### Example

For a bug:
```
Paste the command(s) you ran and the output.
If there was a crash, please include the traceback here.
```

For a feature:
```
Provide sample code that you would hope to run and what it would output.
```
